==> bow-ui-1.1-sources.jar: org/chorem/bow/action/admin/ReIndexationAction.java <==
/*
 * #%L
 * bow
 * 
 * $Id: ReIndexationAction.java 324 2011-08-29 12:21:36Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.1/bow-ui/src/main/java/org/chorem/bow/action/admin/ReIndexationAction.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.action.admin;

import org.chorem.bow.BowSession;
import org.chorem.bow.action.BowBaseAction;
import org.nuiton.wikitty.WikittyProxy;

/**
 * Lance la reindexation solr
 *
 * @author poussin
 */
public class ReIndexationAction extends BowBaseAction {

    private static final long serialVersionUID = 6226574522402739559L;

    @Override
    public String execute() {
        try {
            BowSession session = getBowSession();
            if (session.isAdmin()) { //If is admin
                WikittyProxy proxy = getBowProxy();

                proxy.getWikittyService().syncSearchEngine(proxy.getSecurityToken());
                addActionMessage(_("bow.admin.reIndexationDone"));
            }
        } catch (Exception eee) {
            addActionError(("bow.error.internal"));
            log.error(eee.getMessage(), eee);
        }
        return SUCCESS;
    }
}

==> bow-ui-1.2-sources.jar: org/chorem/bow/action/admin/ReIndexationAction.java <==
/*
 * #%L
 * bow
 * 
 * $Id: ReIndexationAction.java 360 2013-09-24 17:54:39Z bpoussin $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.2/bow-ui/src/main/java/org/chorem/bow/action/admin/ReIndexationAction.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.action.admin;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.bow.BowProxy;
import org.chorem.bow.BowSession;
import org.chorem.bow.action.BowBaseAction;

/**
 * Lance la reindexation solr
 *
 * @author poussin
 */
public class ReIndexationAction extends BowBaseAction {

    private static final long serialVersionUID = 6226574522402739559L;
    
    private static Log log = LogFactory.getLog(ReIndexationAction.class);

    @Override
    public String execute() {
        try {
            BowSession session = getBowSession();
            if (session.isAdmin()) { //If is admin
                BowProxy proxy = getBowProxy();

                proxy.syncSearchEngine();
                addActionMessage(_("bow.admin.reIndexationDone"));
            }
        } catch (Exception eee) {
            addActionError(("bow.error.internal"));
            log.error(eee.getMessage(), eee);
        }
        return SUCCESS;
    }

    static public void main(String ... args) {
        BowProxy proxy = BowProxy.getInstance(null);
        proxy.getWikittyService().syncSearchEngine(null);
    }
}
